@@ -6,7 +6,7 @@ use utf8;
 use warnings;
 
 # Version.
-our $VERSION = 0.14;
+our $VERSION = 0.15;
 
 # Modules.
 use Acme::CPANAuthors::Register(
@@ -18,6 +18,7 @@ use Acme::CPANAuthors::Register(
 	'JANPAZ' => 'Jan Pazdziora',
 	'JANPOM' => 'Jan Pomikálek',
 	'JENDA' => 'Jan Krynický',
+	'JIRA' => 'Jiří Pavlovský',
 	'JSPICAK' => 'Jakub Špičák',
 	'KLE' => 'Petr Kletečka',
 	'KOLCON' => 'Luboš Kolouch',
@@ -57,11 +58,12 @@ Acme::CPANAuthors::Czech - We are Czech CPAN authors.
 
  use Acme::CPANAuthors;
  my $authors = Acme::CPANAuthors->new('Czech');
- my $number = $authors->count;
- my @ids = $authors->id;
- my @distors = $authors->distributions('JANPAZ');
  my $url = $authors->avatar_url('TRIPIE');
+ my $number = $authors->count;
+ my @distors = $authors->distributions('JANPAZ');
+ my @ids = $authors->id;
  my $kwalitee = $authors->kwalitee('RUS');
+ my $name = $authors->name('CHOROBA');
 
 =head1 DESCRIPTION
  
@@ -86,7 +88,7 @@ See documentation for L<Acme::CPANAuthors> for more details.
  print "Count of Czech CPAN authors: $count\n";
 
  # Output:
- # Count of Czech CPAN authors: 29
+ # Count of Czech CPAN authors: 30
 
 =head1 EXAMPLE2
 
@@ -117,27 +119,28 @@ See documentation for L<Acme::CPANAuthors> for more details.
  #     [5]  "JANPAZ",
  #     [6]  "JANPOM",
  #     [7]  "JENDA",
- #     [8]  "JSPICAK",
- #     [9]  "KLE",
- #     [10] "KOLCON",
- #     [11] "MAJLIS",
- #     [12] "MILSO",
- #     [13] "MJFO",
- #     [14] "PAJAS",
- #     [15] "PASKY",
- #     [16] "PEK",
- #     [17] "POPEL",
- #     [18] "PSME",
- #     [19] "RUR",
- #     [20] "RVASICEK",
- #     [21] "SEIDLJAN",
- #     [22] "SKIM",
- #     [23] "SMRZ",
- #     [24] "STRAKA",
- #     [25] "TKR",
- #     [26] "TRIPIE",
- #     [27] "ZEMAN",
- #     [28] "ZOUL"
+ #     [8]  "JIRA",
+ #     [9]  "JSPICAK",
+ #     [10]  "KLE",
+ #     [11] "KOLCON",
+ #     [12] "MAJLIS",
+ #     [13] "MILSO",
+ #     [14] "MJFO",
+ #     [15] "PAJAS",
+ #     [16] "PASKY",
+ #     [17] "PEK",
+ #     [18] "POPEL",
+ #     [19] "PSME",
+ #     [20] "RUR",
+ #     [21] "RVASICEK",
+ #     [22] "SEIDLJAN",
+ #     [23] "SKIM",
+ #     [24] "SMRZ",
+ #     [25] "STRAKA",
+ #     [26] "TKR",
+ #     [27] "TRIPIE",
+ #     [28] "ZEMAN",
+ #     [29] "ZOUL"
  # ]
 
 =head1 DEPENDENCIES
@@ -160,6 +163,6 @@ BSD license.
 
 =head1 VERSION
 
-0.14
+0.15
 
 =cut
